@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileAccess.h,v 1.113 2009/07/21 11:30:34 lav Exp $ */
+/* $Id: FileAccess.h,v 1.114 2010/02/05 14:34:48 lav Exp $ */
 
 #ifndef FILEACCESS_H
 #define FILEACCESS_H
@@ -145,7 +145,7 @@ protected:
    int	 saved_errno;
 
    void	 ExpandTildeInCWD();
-   const char *ExpandTildeStatic(const char *s);
+   const char *ExpandTildeStatic(const char *s) const;
 
    xstring real_cwd;
    void set_real_cwd(const char *c)
@@ -184,12 +184,12 @@ protected:
 
    FileAccess *next;
    static FileAccess *chain;
-   FileAccess *FirstSameSite() { return NextSameSite(0); }
-   FileAccess *NextSameSite(FileAccess *);
+   FileAccess *FirstSameSite() const { return NextSameSite(0); }
+   FileAccess *NextSameSite(FileAccess *) const;
 
-   StringSet *MkdirMakeSet(); // splits the path for mkdir -p
+   StringSet *MkdirMakeSet() const; // splits the path for mkdir -p
 
-   int device_prefix_len(const char *path);
+   int device_prefix_len(const char *path) const;
 
 public:
    virtual const char *GetProto() const = 0; // http, ftp, file etc
