@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FtpListInfo.cc,v 1.63 2007/08/15 07:00:06 lav Exp $ */
+/* $Id: FtpListInfo.cc,v 1.65 2009/09/15 07:56:29 lav Exp $ */
 
 #include <config.h>
 #include "FtpListInfo.h"
@@ -220,6 +220,8 @@ FileInfo *ParseFtpLongList_UNIX(char *line,int *err,const char *tz)
    int	 tmp;
    if(sscanf(line,"total %d",&tmp)==1)
       return 0;
+   if(!strncasecmp(line,"Status of ",10))
+      return 0;	  // STAT output.
    if(strchr("bcpsD",line[0])) // block, char, pipe, socket, Door.
       return 0;
 
