@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,12 +18,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: GetJob.cc,v 1.29 2007/12/28 14:55:13 lav Exp $ */
+/* $Id: GetJob.cc,v 1.33 2010/01/21 08:22:26 lav Exp $ */
 
 #include <config.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include <stddef.h>
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -63,7 +64,8 @@ FileCopyPeer *GetJob::SrcLocal(const char *src)
 }
 FileCopyPeer *GetJob::DstLocal(const char *dst)
 {
-   int flags=O_WRONLY|O_CREAT|(truncate_target_first?O_TRUNC:0);
+   bool clobber=res_clobber.QueryBool(0);
+   int flags=O_WRONLY|O_CREAT|(truncate_target_first?O_TRUNC:0)|(clobber?0:O_EXCL);
    dst=expand_home_relative(dst);
    const char *f=(cwd && dst[0]!='/') ? dir_file(cwd,dst) : dst;
    if(truncate_target_first && res_make_backup.QueryBool(0))
@@ -74,7 +76,7 @@ FileCopyPeer *GetJob::DstLocal(const char *dst)
       {
 	 if(st.st_size>0 && S_ISREG(st.st_mode))
 	 {
-	    if(!res_clobber.QueryBool(0))
+	    if(!clobber)
 	    {
 	       eprintf(_("%s: %s: file already exists and xfer:clobber is unset\n"),op,dst);
 	       errors++;
@@ -97,12 +99,12 @@ FileCopyPeer *GetJob::DstLocal(const char *dst)
 bool GetJob::IsRemoteNonURL(const ParsedURL &url,FA::open_mode mode)
 {
    // store & put || !store & get
-   return (!url.proto && (mode==FA::STORE ^ !reverse));
+   return (!url.proto && ((mode==FA::STORE)^!reverse));
 }
 bool GetJob::IsLocalNonURL(const ParsedURL &url,FA::open_mode mode)
 {
    // store & get || !store & put
-   return (!url.proto && (mode==FA::STORE ^ reverse));
+   return (!url.proto && ((mode==FA::STORE)^reverse));
 }
 bool GetJob::IsLocal(const ParsedURL &url)
 {
