@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: GetJob.h,v 1.15 2007/04/23 07:11:46 lav Exp $ */
+/* $Id: GetJob.h,v 1.17 2008/11/27 05:56:18 lav Exp $ */
 
 #ifndef GETJOB_H
 #define GETJOB_H
@@ -29,8 +29,10 @@ class GetJob : public CopyJobEnv
 {
    FileCopyPeer *SrcLocal(const char *src);
    FileCopyPeer *DstLocal(const char *dst);
-   FileCopyPeer *CreateCopyPeer(const ParsedURL &url,FA::open_mode mode);
+   FileCopyPeer *CreateCopyPeer(const ParsedURL &url,const char *path,FA::open_mode mode);
+   FileCopyPeer *CreateCopyPeer(const char *path,FA::open_mode mode);
    bool IsRemoteNonURL(const ParsedURL &url,FA::open_mode mode);
+   bool IsLocalNonURL(const ParsedURL &url,FA::open_mode mode);
    static bool IsLocal(const ParsedURL &url);
 
 protected:
