@@ -1,11 +1,11 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2007 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,83 +18,69 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Job.cc,v 1.39 2006/08/02 13:44:26 lav Exp $ */
+/* $Id: Job.cc,v 1.51 2009/08/13 09:42:44 lav Exp $ */
 
 #include <config.h>
 #include <stdlib.h>
 #include <errno.h>
 #include <assert.h>
 #include "Job.h"
+#include "misc.h"
 
 Job *Job::chain;
+#define waiting_num waiting.count()
 
 Job::Job()
 {
    next=chain;
    chain=this;
-   cmdline=0;
    parent=0;
-   waiting=0;
-   waiting_num=0;
-   waiting_alloc=0;
    jobno=-1;
    fg=false;
-   fg_data=0;
+   job_prepared_to_die=false;
 }
 
 void  Job::AllocJobno()
 {
    jobno=0;
-   for(Job *scan=chain; scan; scan=scan->next)
+   ListScan(Job,chain,next)
       if(scan!=this && scan->jobno>=jobno)
 	 jobno=scan->jobno+1;
 }
 
-Job::~Job()
+void Job::PrepareToDie()
 {
-   xfree(waiting);
-   waiting=0;
-   waiting_num=0;
    // reparent or kill children (hm, that's sadistic)
+   ListScan(Job,chain,next)
    {
-      for(Job *scan=chain; scan; )
+      if(scan->parent==this)
       {
-	 if(scan->parent==this)
+	 if(scan->jobno!=-1 && this->parent)
+	    scan->parent=this->parent;
+	 else
 	 {
-	    if(scan->jobno!=-1 && this->parent)
-	       scan->parent=this->parent;
-	    else
-	    {
-	       scan->parent=0;
-	       scan->deleting=true;
-	    }
+	    scan->parent=0;
+	    scan->DeleteLater();
 	 }
-	 scan=scan->next;
       }
    }
    // if parent waits for the job, make it stop
    if(parent)
       parent->RemoveWaiting(this);
-   // now, delete the job from the list
-   {
-      for(Job **scan=&chain; *scan; scan=&(*scan)->next)
-      {
-	 if(*scan==this)
-	 {
-	    *scan=next;
-	    break;
-	 }
-      }
-   }
+   fg_data=0;
+   waiting.unset();
+   ListDel(Job,chain,this,next);
+   job_prepared_to_die=true;
+}
 
-   xfree(cmdline);
-   if(fg_data)
-      delete fg_data;
+Job::~Job()
+{
+   assert(job_prepared_to_die);
 }
 
 Job *Job::FindJob(int n)
 {
-   for(Job *scan=chain; scan; scan=scan->next)
+   ListScan(Job,chain,next)
    {
       if(scan->jobno==n)
 	 return scan;
@@ -104,7 +90,7 @@ Job *Job::FindJob(int n)
 
 Job *Job::FindWhoWaitsFor(Job *j)
 {
-   for(Job *scan=chain; scan; scan=scan->next)
+   ListScan(Job,chain,next)
    {
       if(scan->WaitsFor(j))
 	 return scan;
@@ -114,12 +100,7 @@ Job *Job::FindWhoWaitsFor(Job *j)
 
 bool Job::WaitsFor(Job *j)
 {
-   for(int i=0; i<waiting_num; i++)
-   {
-      if(waiting[i]==j)
-	 return true;
-   }
-   return false;
+   return waiting.search(j)>=0;
 }
 
 Job *Job::FindDoneAwaitedJob()
@@ -134,23 +115,23 @@ Job *Job::FindDoneAwaitedJob()
 
 void Job::WaitForAllChildren()
 {
-   for(Job *scan=chain; scan; scan=scan->next)
+   ListScan(Job,chain,next)
    {
       if(scan->parent==this)
 	 AddWaiting(scan);
    }
 }
+void Job::AllWaitingFg()
+{
+   for(int i=0; i<waiting_num; i++)
+      waiting[i]->Fg();
+}
 
 void Job::ReplaceWaiting(Job *from,Job *to)
 {
-   for(int i=0; i<waiting_num; i++)
-   {
-      if(waiting[i]==from)
-      {
-	 waiting[i]=to;
-	 return;
-      }
-   }
+   int i=waiting.search(from);
+   if(i>=0)
+      waiting[i]=to;
 }
 
 void Job::AddWaiting(Job *j)
@@ -158,23 +139,14 @@ void Job::AddWaiting(Job *j)
    if(j==0 || this->WaitsFor(j))
       return;
    assert(FindWhoWaitsFor(j)==0);
-   waiting_num++;
-   if(waiting_alloc<waiting_num)
-      waiting=(Job**)xrealloc(waiting,(waiting_alloc+=4)*sizeof(*waiting));
-   waiting[waiting_num-1]=j;
+   j->SetParentFg(this);
+   waiting.append(j);
 }
-void Job::RemoveWaiting(Job *j)
+void Job::RemoveWaiting(const Job *j)
 {
-   for(int i=0; i<waiting_num; i++)
-   {
-      if(waiting[i]==j)
-      {
-	 waiting_num--;
-	 if(i<waiting_num)
-	    memmove(waiting+i,waiting+i+1,(waiting_num-i)*sizeof(*waiting));
-	 return;
-      }
-   }
+   int i=waiting.search(const_cast<Job*>(j));
+   if(i>=0)
+      waiting.remove(i);
 }
 
 class KilledJob : public Job
@@ -187,15 +159,16 @@ public:
 
 void Job::Kill(Job *j)
 {
+   if(j->AcceptSig(SIGTERM)!=WANTDIE)
+      return;
    if(j->parent && j->parent->WaitsFor(j))
    {
       // someone waits for termination of this job, so
       // we have to simulate normal death...
       Job *r=new KilledJob();
       r->parent=j->parent;
-      r->cmdline=j->cmdline,j->cmdline=0;
-      r->waiting=j->waiting,j->waiting=0;
-      r->waiting_num=j->waiting_num,j->waiting_num=0;
+      r->cmdline.set(j->cmdline);
+      r->waiting.move_here(j->waiting);
       j->parent->ReplaceWaiting(j,r);
    }
    assert(FindWhoWaitsFor(j)==0);
@@ -211,14 +184,14 @@ void Job::Kill(int n)
 
 void Job::KillAll()
 {
-   for(Job *scan=chain; scan; scan=scan->next)
+   ListScan(Job,chain,next)
       if(scan->jobno>=0)
 	 Job::Kill(scan);
    CollectGarbage();
 }
 void Job::Cleanup()
 {
-   for(Job *scan=chain; scan; scan=scan->next)
+   ListScan(Job,chain,next)
       Job::Kill(scan);
    CollectGarbage();
 }
@@ -237,58 +210,42 @@ void  Job::SendSig(int n,int sig)
 int   Job::NumberOfJobs()
 {
    int count=0;
-   for(Job *scan=chain; scan; scan=scan->next)
-      if(!scan->Done())
+   ListScan(Job,chain,next)
+      if(!scan->running && !scan->Done())
 	 count++;
    return count;
 }
 
-static int jobno_compare(const void *a,const void *b)
+static int jobno_compare(Job *const*a,Job *const*b)
 {
-   Job *ja=*(Job*const*)a;
-   Job *jb=*(Job*const*)b;
-   return ja->jobno-jb->jobno;
+   return (*a)->jobno-(*b)->jobno;
 }
 
 void  Job::SortJobs()
 {
-   int count=0;
-   Job *scan;
-   for(scan=chain; scan; scan=scan->next)
-      count++;
+   xarray<Job*> arr;
 
-   if(count==0)
-      return;
-
-   Job **arr=(Job**)alloca(count*sizeof(*arr));
-   count=0;
-   for(scan=chain; scan; scan=scan->next)
-      arr[count++]=scan;
-
-   qsort(arr,count,sizeof(*arr),jobno_compare);
+   ListScan(Job,chain,next)
+      arr.append(scan);
+   arr.qsort(jobno_compare);
 
    chain=0;
+   int count=arr.count();
    while(count--)
-   {
-      arr[count]->next=chain;
-      chain=arr[count];
-   }
+      ListAdd(Job,chain,arr[count],next);
 
-   for(scan=chain; scan; scan=scan->next)
-   {
-      if(scan->waiting_num>1)
-	 qsort(scan->waiting,scan->waiting_num,sizeof(*scan->waiting),jobno_compare);
-   }
+   ListScan(Job,chain,next)
+      scan->waiting.qsort(jobno_compare);
 }
 
 void Job::PrintJobTitle(int indent,const char *suffix)
 {
-   if(jobno<0 && cmdline==0)
+   if(jobno<0 && !cmdline)
       return;
    printf("%*s",indent,"");
    if(jobno>=0)
       printf("[%d] ",jobno);
-   printf("%s",cmdline?cmdline:"?");
+   printf("%s",cmdline?cmdline.get():"?");
    if(suffix)
       printf(" %s",suffix);
    printf("\n");
@@ -300,7 +257,7 @@ void Job::ListOneJob(int verbose,int indent,const char *suffix)
    PrintStatus(verbose);
    for(int i=0; i<waiting_num; i++)
    {
-      if(waiting[i]->jobno<0 && waiting[i]!=this && waiting[i]->cmdline==0)
+      if(waiting[i]->jobno<0 && waiting[i]!=this && !waiting[i]->cmdline)
 	 waiting[i]->ListOneJob(verbose,indent+1);
    }
 }
@@ -324,11 +281,9 @@ void  Job::ListJobs(int verbose,int indent)
 	 waiting[i]->ListOneJobRecursively(verbose,indent);
    }
 
-   for(Job *scan=chain; scan; scan=scan->next)
-   {
+   ListScan(Job,chain,next)
       if(scan->parent==this && !scan->Done() && !this->WaitsFor(scan))
 	 scan->ListOneJobRecursively(verbose,indent);
-   }
 }
 
 void  Job::ListDoneJobs()
@@ -336,13 +291,13 @@ void  Job::ListDoneJobs()
    SortJobs();
 
    FILE *f=stdout;
-   for(Job *scan=chain; scan; scan=scan->next)
+   ListScan(Job,chain,next)
    {
       if(scan->jobno>=0 && (scan->parent==this || scan->parent==0)
          && !scan->deleting && scan->Done())
       {
 	 fprintf(f,_("[%d] Done (%s)"),scan->jobno,
-	    scan->cmdline?scan->cmdline:"?");
+	    scan->cmdline?scan->cmdline.get():"?");
 	 const char *this_url=this->GetConnectURL();
 	 this_url=alloca_strdup(this_url); // save it from overwriting.
 	 const char *that_url=scan->GetConnectURL();
@@ -356,11 +311,11 @@ void  Job::ListDoneJobs()
 
 void  Job::BuryDoneJobs()
 {
-   for(Job *scan=chain; scan; scan=scan->next)
+   ListScan(Job,chain,next)
    {
       if((scan->parent==this || scan->parent==0) && scan->jobno>=0
 		  && !scan->deleting && scan->Done())
-	 scan->deleting=true;
+	 scan->DeleteLater();
    }
    CollectGarbage();
 }
@@ -390,23 +345,6 @@ void Job::eprintf(const char *fmt,...)
 }
 
 
-FileAccess *SessionJob::Clone() const
-{
-   return session->Clone();
-}
-
-SessionJob::SessionJob(FileAccess *f)
-{
-   session=f;
-}
-
-SessionJob::~SessionJob()
-{
-   if(session)
-      Reuse(session);
-   session=0;
-}
-
 void SessionJob::PrintStatus(int v,const char *prefix)
 {
    if(v<2 || !session)
@@ -510,7 +448,7 @@ int Job::AcceptSig(int s)
    return WANTDIE;
 }
 
-void Job::ShowRunStatus(StatusLine *sl)
+void Job::ShowRunStatus(const SMTaskRef<StatusLine>& sl)
 {
    if(waiting_num==0)
       return;
@@ -526,17 +464,15 @@ void Job::ShowRunStatus(StatusLine *sl)
 
 Job *Job::FindAnyChild()
 {
-   for(Job *scan=chain; scan; scan=scan->next)
-   {
+   ListScan(Job,chain,next)
       if(scan->parent==this && scan->jobno>=0)
       	 return scan;
-   }
    return 0;
 }
 
 void Job::lftpMovesToBackground_ToAll()
 {
-   for(Job *scan=chain; scan; scan=scan->next)
+   ListScan(Job,chain,next)
       scan->lftpMovesToBackground();
 }
 
@@ -552,11 +488,13 @@ bool Job::CheckForWaitLoop(Job *parent)
 
 void Job::WaitDone()
 {
+   ref_count++;	  // keep me in memory
    for(;;)
    {
       SMTask::Schedule();
-      if(Done())
+      if(deleting || Done())
 	 break;
       SMTask::Block();
    }
+   ref_count--;
 }
