@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: NetAccess.cc,v 1.105 2008/05/22 14:50:30 lav Exp $ */
+/* $Id: NetAccess.cc,v 1.108 2009/09/15 07:56:29 lav Exp $ */
 
 #include <config.h>
 
@@ -26,23 +26,7 @@
 #include <assert.h>
 #include <math.h>
 #include <sys/types.h>
-#include <netinet/in.h>
-#ifdef HAVE_NETINET_IN_SYSTM_H
-# include <netinet/in_systm.h>
-#endif
-#ifdef HAVE_NETINET_IP_H
-# include <netinet/ip.h>
-#endif
-#ifdef HAVE_NETINET_TCP_H
-# include <netinet/tcp.h>
-#endif
-#include <arpa/inet.h>
-#ifdef HAVE_SYS_IOCTL_H
-# include <sys/ioctl.h>
-#endif
-#ifdef HAVE_TERMIOS_H
-# include <termios.h>
-#endif
+
 #include "NetAccess.h"
 #include "log.h"
 #include "url.h"
@@ -122,152 +106,6 @@ void NetAccess::Reconfig(const char *name)
       rate_limit->Reconfig(name,c);
 }
 
-static int one=1;
-void NetAccess::KeepAlive(int sock)
-{
-   setsockopt(sock,SOL_SOCKET,SO_KEEPALIVE,(char*)&one,sizeof(one));
-}
-void NetAccess::MinimizeLatency(int sock)
-{
-#ifdef IP_TOS
-   int tos = IPTOS_LOWDELAY;
-   setsockopt(sock, IPPROTO_IP, IP_TOS, (char *)&tos, sizeof(int));
-#endif
-}
-void NetAccess::MaximizeThroughput(int sock)
-{
-#ifdef IP_TOS
-   int tos = IPTOS_THROUGHPUT;
-   setsockopt(sock, IPPROTO_IP, IP_TOS, (char *)&tos, sizeof(int));
-#endif
-}
-void NetAccess::ReuseAddress(int sock)
-{
-   setsockopt(sock,SOL_SOCKET,SO_REUSEADDR,(char*)&one,sizeof(one));
-}
-void NetAccess::SetSocketBuffer(int sock)
-{
-   if(socket_buffer==0)
-      return;
-   if(-1==setsockopt(sock,SOL_SOCKET,SO_SNDBUF,(char*)&socket_buffer,sizeof(socket_buffer)))
-      LogError(1,"setsockopt(SO_SNDBUF,%d): %s",socket_buffer,strerror(errno));
-   if(-1==setsockopt(sock,SOL_SOCKET,SO_RCVBUF,(char*)&socket_buffer,sizeof(socket_buffer)))
-      LogError(1,"setsockopt(SO_RCVBUF,%d): %s",socket_buffer,strerror(errno));
-}
-void NetAccess::SetSocketMaxseg(int sock)
-{
-#ifndef SOL_TCP
-# define SOL_TCP IPPROTO_TCP
-#endif
-#ifdef TCP_MAXSEG
-   if(socket_maxseg==0)
-      return;
-   if(-1==setsockopt(sock,SOL_TCP,TCP_MAXSEG,(char*)&socket_maxseg,sizeof(socket_maxseg)))
-      LogError(1,"setsockopt(TCP_MAXSEG,%d): %s",socket_maxseg,strerror(errno));
-#endif
-}
-
-int NetAccess::SocketCreate(int af,int type,int proto)
-{
-   int s=socket(af,type,proto);
-   if(s<0)
-      return s;
-   const char *b=0;
-   sockaddr_u bind_addr;
-   memset(&bind_addr,0,sizeof(bind_addr));
-   bind_addr.in.sin_family=af;
-   if(af==AF_INET)
-   {
-      b=ResMgr::Query("net:socket-bind-ipv4",hostname);
-      if(!(b && b[0] && inet_pton(af,b,&bind_addr.in.sin_addr)))
-	 b=0;
-   }
-#if INET6
-   else if(af==AF_INET6)
-   {
-      b=ResMgr::Query("net:socket-bind-ipv6",hostname);
-      if(!(b && b[0] && inet_pton(af,b,&bind_addr.in6.sin6_addr)))
-	 b=0;
-   }
-#endif
-   if(b)
-   {
-      int res=bind_addr.bind_to(s);
-      if(res==-1)
-	 LogError(0,"bind(socket, %s): %s",b,strerror(errno));
-   }
-   return s;
-}
-int NetAccess::SocketCreateTCP(int af)
-{
-   return SocketCreate(af,SOCK_STREAM,IPPROTO_TCP);
-}
-int NetAccess::SocketConnect(int fd,const sockaddr_u *u)
-{
-   // some systems have wrong connect() prototype, so we have to cast off const.
-   // in any case, connect does not alter the address.
-   int res=connect(fd,(sockaddr*)&u->sa,SocketAddrLen(u));
-   if(res!=-1)
-      UpdateNow(); // if non-blocking doesn't work
-   return res;
-}
-
-#ifdef TIOCOUTQ
-static bool TIOCOUTQ_returns_free_space;
-static bool TIOCOUTQ_works;
-static bool TIOCOUTQ_tested;
-static void test_TIOCOUTQ()
-{
-   int sock=socket(PF_INET,SOCK_STREAM,IPPROTO_TCP);
-   if(sock==-1)
-      return;
-   TIOCOUTQ_tested=true;
-   int avail=-1;
-   socklen_t len=sizeof(avail);
-   if(getsockopt(sock,SOL_SOCKET,SO_SNDBUF,(char*)&avail,&len)==-1)
-      avail=-1;
-   int buf=-1;
-   if(ioctl(sock,TIOCOUTQ,&buf)==-1)
-      buf=-1;
-   if(buf>=0 && avail>0 && (buf==0 || buf==avail))
-   {
-      TIOCOUTQ_works=true;
-      TIOCOUTQ_returns_free_space=(buf==avail);
-   }
-   close(sock);
-}
-#endif
-int NetAccess::SocketBuffered(int sock)
-{
-#ifdef TIOCOUTQ
-   if(!TIOCOUTQ_tested)
-      test_TIOCOUTQ();
-   if(!TIOCOUTQ_works)
-      return 0;
-   int buffer=0;
-   if(TIOCOUTQ_returns_free_space)
-   {
-      socklen_t len=sizeof(buffer);
-      if(getsockopt(sock,SOL_SOCKET,SO_SNDBUF,(char*)&buffer,&len)==-1)
-	 return 0;
-      int avail=buffer;
-      if(ioctl(sock,TIOCOUTQ,&avail)==-1)
-	 return 0;
-      if(avail>buffer)
-	 return 0; // something wrong
-      buffer-=avail;
-      buffer=buffer*3/4; // approx...
-   }
-   else
-   {
-      if(ioctl(sock,TIOCOUTQ,&buffer)==-1)
-	 return 0;
-   }
-   return buffer;
-#else
-   return 0;
-#endif
-}
 int NetAccess::CheckHangup(const struct pollfd *pfd,int num)
 {
    for(int i=0; i<num; i++)
@@ -650,7 +488,7 @@ do_again:
 	    // tilde is special.
 	    if(file->name[0]=='~')
 	    {
-	       file->name.set_substr(0,1,"./");
+	       file->name.set_substr(0,0,"./");
 	       need_resort=true;
 	    }
 	 }
