@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: SFtp.cc,v 1.82 2008/11/27 05:56:27 lav Exp $ */
+/* $Id: SFtp.cc,v 1.86 2009/07/17 13:07:29 lav Exp $ */
 
 #include <config.h>
 #include "SFtp.h"
@@ -71,7 +71,6 @@ bool SFtp::GetBetterConnection(int level,bool limit_reached)
 int SFtp::Do()
 {
    int m=STALL;
-   int count;
    const char *b;
    int s;
 
@@ -130,7 +129,6 @@ int SFtp::Do()
 
       // walk through SFtp classes and try to find identical idle session
       // first try "easy" cases of session take-over.
-      count=CountConnections();
       for(int i=0; i<3; i++)
       {
 	 bool limit_reached=(connection_limit>0
@@ -606,8 +604,7 @@ void SFtp::SendRequest()
 	 SetError(NOT_SUPP);
 	 break;
       }
-      char *file1_wire_path=alloca_strdup(WirePath(file1));
-      SendRequest(new Request_RENAME(WirePath(file),file1_wire_path,
+      SendRequest(new Request_RENAME(WirePath(file),WirePath(file1),
 			SSH_FXF_RENAME_NATIVE,protocol_version),Expect::DEFAULT);
       state=WAITING;
       break;
@@ -622,6 +619,12 @@ void SFtp::SendRequest()
       break;
    }
    case MAKE_DIR:
+      if(mkdir_p)
+      {
+	 Ref<StringSet> dirs(MkdirMakeSet());
+	 for(int i=0; i<dirs->Count(); i++)
+	    SendRequest(new Request_MKDIR(WirePath(dirs->String(i)),protocol_version),Expect::IGNORE);
+      }
       SendRequest(new Request_MKDIR(WirePath(file),protocol_version),Expect::DEFAULT);
       state=WAITING;
       break;
@@ -1000,6 +1003,9 @@ int SFtp::HandleReplies()
    if(state!=CONNECTING_2)
       m|=HandlePty();
 
+   if(!recv_buf)
+      return MOVED;
+
    int i=0;
    Expect *ooo_scan=ooo_chain;
    while(ooo_scan)
@@ -1921,7 +1927,7 @@ const char *SFtp::utf8_to_lc(const char *s)
    int len;
    recv_translate->Get(&s,&len);
    recv_translate->Skip(len);
-   return s;
+   return xstring::get_tmp(s,len);
 }
 const char *SFtp::lc_to_utf8(const char *s)
 {
@@ -1934,7 +1940,7 @@ const char *SFtp::lc_to_utf8(const char *s)
    int len;
    send_translate->Get(&s,&len);
    send_translate->Skip(len);
-   return s;
+   return xstring::get_tmp(s,len);
 }
 
 FileSet *SFtp::GetFileSet()
