@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: SMTask.cc,v 1.54 2008/05/16 08:45:01 lav Exp $ */
+/* $Id: SMTask.cc,v 1.56 2008/11/27 05:56:28 lav Exp $ */
 
 #include <config.h>
 #include <assert.h>
@@ -129,11 +129,17 @@ SMTask::~SMTask()
    }
 }
 
+void SMTask::DeleteLater()
+{
+   deleting=true;
+   PrepareToDie();
+}
 void SMTask::Delete(SMTask *task)
 {
    if(!task)
       return;
-   task->deleting=true;
+   task->DeleteLater();
+   // if possible, delete now.
    if(!task->running && !task->ref_count)
       delete task;
 }
