@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: StringSet.cc,v 1.7 2008/11/27 05:56:31 lav Exp $ */
+/* $Id: StringSet.cc,v 1.8 2009/03/20 12:28:04 lav Exp $ */
 
 #include <config.h>
 #include "StringSet.h"
@@ -26,6 +26,11 @@
 
 #define set_size set.count()
 
+StringSet::StringSet() {}
+StringSet::StringSet(const char *const *s,int n) { Assign(s,n); }
+StringSet::StringSet(const StringSet &o) { Assign(o.set.get(),o.set.count()); }
+StringSet::StringSet(const char *s) { Assign(&s,1); }
+
 bool StringSet::IsEqual(const char *const *set1,int n1) const
 {
    if(set_size!=n1)
