@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: StringSet.h,v 1.7 2008/11/27 05:56:31 lav Exp $ */
+/* $Id: StringSet.h,v 1.8 2009/03/20 12:28:04 lav Exp $ */
 
 #ifndef STRINGSET_H
 #define STRINGSET_H
@@ -32,10 +32,10 @@ class StringSet
    const StringSet &operator=(const StringSet &); // disable assignment
 
 public:
-   StringSet() {}
-   StringSet(const char *const *s,int n) { Assign(s,n); }
-   StringSet(const StringSet &o) { Assign(o.set.get(),o.set.count()); }
-   StringSet(const char *s) { Assign(&s,1); }
+   StringSet();
+   StringSet(const char *const *s,int n);
+   StringSet(const StringSet &o);
+   StringSet(const char *s);
 
    void Empty() { set.truncate(); }
    void Assign(const char *const *s,int n);
