@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ftpclass.h,v 1.160 2009/01/27 14:04:56 lav Exp $ */
+/* $Id: ftpclass.h,v 1.162 2010/03/05 10:44:12 lav Exp $ */
 
 #ifndef FTPCLASS_H
 #define FTPCLASS_H
@@ -87,6 +87,7 @@ class Ftp : public NetAccess
       bool translation_activated;
       bool proxy_is_http; // true when connection was established via http proxy.
       bool may_show_password;
+      bool can_do_pasv;
 
       int multiline_code; // the code of multiline response.
       int sync_wait;	  // number of commands in flight.
@@ -243,18 +244,18 @@ class Ftp : public NetAccess
       void Push(Expect *e);
       void Push(Expect::expect_t e);
       Expect *Pop();
-      Expect *FindLastCWD();
-      int Count() { return count; }
-      bool IsEmpty() { return count==0; }
-      bool Has(Expect::expect_t);
-      bool FirstIs(Expect::expect_t);
+      Expect *FindLastCWD() const;
+      int Count() const { return count; }
+      bool IsEmpty() const { return count==0; }
+      bool Has(Expect::expect_t) const;
+      bool FirstIs(Expect::expect_t) const;
       void Close();
    };
 
    Ref<ExpectQueue> expect;
 
    void  CheckResp(int resp);
-   int	 ReplyLogPriority(int code);
+   int	 ReplyLogPriority(int code) const;
 
    void	 RestCheck(int);
    void  NoFileCheck(int);
@@ -284,8 +285,9 @@ class Ftp : public NetAccess
    pasv_state_t Handle_PASV();
    pasv_state_t Handle_EPSV();
 
-   bool NonError5XX(int act);
-   bool Transient5XX(int act);
+   bool ServerSaid(const char *) const;
+   bool NonError5XX(int act) const;
+   bool Transient5XX(int act) const;
 
    void	 InitFtp();
 
@@ -334,7 +336,7 @@ private:
    // May disconnect.
    bool	 HttpProxyReplyCheck(const SMTaskRef<IOBuffer>&);
 
-   bool	 AbsolutePath(const char *p);
+   bool	 AbsolutePath(const char *p) const;
 
    void MoveConnectionHere(Ftp *o);
    bool GetBetterConnection(int level,bool limit_reached);
@@ -450,7 +452,7 @@ public:
    void  DisconnectNow();
 
    void	 SetFlag(int flag,bool val);
-   int	 GetFlag(int flag) { return flags&flag; }
+   int	 GetFlag(int flag) const { return flags&flag; }
 
    static time_t ConvertFtpDate(const char *);
 
@@ -494,17 +496,17 @@ public:
 	 copy_addr_valid=true;
 	 return true;
       }
-   bool CopyFailed() { return copy_failed; }
-   bool RestartFailed() { return flags&NOREST_MODE; }
-   bool IsPassive() { return flags&PASSIVE_MODE; }
-   bool IsCopyPassive() { return copy_passive; }
+   bool CopyFailed() const { return copy_failed; }
+   bool RestartFailed() const { return flags&NOREST_MODE; }
+   bool IsPassive() const { return flags&PASSIVE_MODE; }
+   bool IsCopyPassive() const { return copy_passive; }
    void CopyAllowStore()
       {
 	 conn->SendCmd2("STOR",file);
 	 expect->Push(new Expect(Expect::TRANSFER));
 	 copy_allow_store=true;
       }
-   bool CopyStoreAllowed() { return copy_allow_store; }
+   bool CopyStoreAllowed() const { return copy_allow_store; }
    bool CopyIsReadyForStore()
       {
 	 if(!expect)
