@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: lftp_rl.c,v 1.15 2005/11/10 06:43:44 lav Exp $ */
+/* $Id: lftp_rl.c,v 1.19 2009/11/17 08:18:37 lav Exp $ */
 
 #include <config.h>
 #include <stdio.h>
@@ -27,7 +27,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include "lftp_rl.h"
-#include "xalloca.h"
 
 /* complete.cc */
 void lftp_line_complete();
@@ -151,7 +150,7 @@ void lftp_rl_init(
    const char *completer_word_break_characters,
    const char *filename_quote_characters,
    char *(*filename_quoting_function)(char *,int,char *),
-   char *(*filename_dequoting_function)(char *,int),
+   char *(*filename_dequoting_function)(const char *,int),
    int (*char_is_quoted_p)(const char *,int))
 {
    rl_readline_name                  =readline_name;
@@ -205,3 +204,11 @@ void lftp_rl_write_history()
       return;
    write_history(lftp_history_file);
 }
+
+void lftp_rl_history_stifle(int s)
+{
+   if(s==0)
+      unstifle_history();
+   else
+      stifle_history(s);
+}
