@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -30,18 +30,19 @@
 #  include <openssl/rand.h>
 # endif
 
+#include "xstring.h"
+
 class lftp_ssl_base
 {
 public:
    bool handshake_done;
    int fd;
-   char *hostname;
+   xstring_c hostname;
    enum handshake_mode_t { CLIENT, SERVER } handshake_mode;
-   char *error;
+   xstring error;
    bool fatal;
 
    lftp_ssl_base(int fd,handshake_mode_t m,const char *host=0);
-   ~lftp_ssl_base();
 
    enum code { RETRY=-2, ERROR=-1, DONE=0 };
 
@@ -106,6 +107,7 @@ public:
    bool want_out();
    void copy_sid(const lftp_ssl_gnutls *);
    void load_keys();
+   void shutdown();
 };
 typedef lftp_ssl_gnutls lftp_ssl;
 #elif USE_OPENSSL
@@ -139,6 +141,7 @@ public:
    bool want_out();
    void copy_sid(const lftp_ssl_openssl *);
    void load_keys();
+   void shutdown();
 };
 typedef lftp_ssl_openssl lftp_ssl;
 #endif
