@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: misc.cc,v 1.97 2008/11/27 05:56:41 lav Exp $ */
+/* $Id: misc.cc,v 1.98 2009/12/18 17:00:42 lav Exp $ */
 
 #include <config.h>
 #include "xmalloc.h"
@@ -64,11 +64,7 @@ const char *dir_file(const char *dir,const char *file)
    if(file[0]=='/')
       return file;
 
-   static xstring buf;
-
-   if(buf && dir==buf) // it is possible to dir_file(dir_file(dir,dir),file)
-      dir=alloca_strdup(dir);
-
+   xstring& buf=xstring::get_tmp();
    size_t len=strlen(dir);
    if(len==0)
       return buf.set(file);
