@@ -1,11 +1,11 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-1997 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2007 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -28,36 +28,29 @@
 
 class mkdirJob : public SessionJob
 {
-   ArgV	 *args;
-   char	 *curr,*first;
-   FA	 *url_session;
+   Ref<ArgV> args;
+   const char *curr,*first;
+   FileAccessRef my_session;
+   FileAccessRefC session;
    int	 failed,file_count;
    bool	 quiet;
    bool	 opt_p;
 
-   FA *Session() { return url_session?url_session:session; }
-   void Reuse()
-      {
-	 if(url_session)
-	 {
-	    SessionPool::Reuse(url_session);
-	    url_session=0;
-	 }
-      }
-
 public:
    int	 Do();
    int	 Done() { return curr==0; }
    int	 ExitCode() { return failed; }
 
-   void	 PrintStatus(int);
-   void	 ShowRunStatus(StatusLine *);
+   void	 PrintStatus(int,const char *);
+   void	 ShowRunStatus(const SMTaskRef<StatusLine>&);
    void	 SayFinal();
 
    mkdirJob(FileAccess *session,ArgV *a);
-   ~mkdirJob();
 
    void	 BeQuiet() { quiet=true; }
+
+   void Fg();
+   void Bg();
 };
 
 #endif // MKDIRJOB_H
