@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: network.cc,v 1.6 2009/09/15 07:56:30 lav Exp $ */
+/* $Id: network.cc,v 1.7 2010/02/05 14:34:48 lav Exp $ */
 
 #include <config.h>
 #include <stdio.h>
@@ -48,6 +48,7 @@
 #include "network.h"
 #include "ResMgr.h"
 #include "ProtoLog.h"
+#include "xstring.h"
 
 sockaddr_u::sockaddr_u()
 {
@@ -81,7 +82,12 @@ int sockaddr_u::port() const
    return 0;
 }
 
-bool sockaddr_u::is_reserved()
+const xstring& sockaddr_u::to_string() const
+{
+   return xstring::format("[%s]:%d",address(),port());
+}
+
+bool sockaddr_u::is_reserved() const
 {
    if(sa.sa_family==AF_INET)
    {
@@ -93,7 +99,7 @@ bool sockaddr_u::is_reserved()
    return false;
 }
 
-bool sockaddr_u::is_multicast()
+bool sockaddr_u::is_multicast() const
 {
    if(sa.sa_family==AF_INET)
    {
@@ -103,7 +109,7 @@ bool sockaddr_u::is_multicast()
    return false;
 }
 
-bool sockaddr_u::is_private()
+bool sockaddr_u::is_private() const
 {
    if(sa.sa_family==AF_INET)
    {
@@ -114,7 +120,7 @@ bool sockaddr_u::is_private()
    }
    return false;
 }
-bool sockaddr_u::is_loopback()
+bool sockaddr_u::is_loopback() const
 {
    if(sa.sa_family==AF_INET)
    {
