@@ -18,13 +18,14 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: pgetJob.cc,v 1.53 2009/03/17 10:59:59 lav Exp $ */
+/* $Id: pgetJob.cc,v 1.56 2010/03/05 14:37:48 lav Exp $ */
 
 #include <config.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <stddef.h>
 #include <assert.h>
+#include <errno.h>
 #include "pgetJob.h"
 #include "url.h"
 #include "misc.h"
@@ -323,9 +324,13 @@ pgetJob::pgetJob(FileCopy *c1,const char *n,int m)
 	 LoadStatus0();
    }
 }
-pgetJob::~pgetJob()
+void pgetJob::PrepareToDie()
 {
    free_chunks();
+   super::PrepareToDie();
+}
+pgetJob::~pgetJob()
+{
 }
 
 pgetJob::ChunkXfer *pgetJob::NewChunk(const char *remote,off_t start,off_t limit)
@@ -389,8 +394,18 @@ void pgetJob::LoadStatus0()
       return;
 
    FILE *f=fopen(status_file,"r");
-   if(!f)
+   if(!f) {
+      int saved_errno=errno;
+      // Probably the file is already complete
+      // or it was previously downloaded by plain get.
+      struct stat st;
+      if(stat(c->put->GetLocal()->full_name,&st)==-1)
+	 return;
+      Log::global->Format(0,"pget: %s: cannot open (%s), resuming at the file end\n",
+	 status_file.get(),strerror(saved_errno));
+      c->SetRange(st.st_size,FILE_END);
       return;
+   }
 
    long long size;
    if(fscanf(f,"size=%lld\n",&size)<1)
