@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: resource.cc,v 1.161 2009/03/17 10:59:59 lav Exp $ */
+/* $Id: resource.cc,v 1.164 2010/03/18 08:09:38 lav Exp $ */
 
 #include <config.h>
 
@@ -211,6 +211,7 @@ static ResType lftp_vars[] = {
    {"ftp:ssl-use-ccc",		 "no",	  ResMgr::BoolValidate,0},
    {"ftp:ssl-shutdown-timeout",	 "5",	  ResMgr::TimeIntervalValidate,0},
    {"ftp:ssl-data-use-keys",	 "yes",	  ResMgr::BoolValidate,0},
+   {"ftp:ssl-copy-sid",		 "yes",	  ResMgr::BoolValidate,0},
    {"ftps:initial-prot",	 "",	  ProtValidate,0},
 #endif
    {"ftp:stat-interval",	 "1",	  ResMgr::TimeIntervalValidate,0},
@@ -240,7 +241,7 @@ static ResType lftp_vars[] = {
    {"ftp:waiting-150-timeout",	 "5",	  ResMgr::TimeIntervalValidate,0},
 #define RETRY_530 \
    "too many|overloaded|try (again |back )?later|is restricted to|"\
-   "maximum number|number of connect|only.*session.*allowed|more connection|already connected"
+   "maximum number|number of connect|only.*session.*allowed|more connection|already connected|simultaneous login"
    {"ftp:retry-530",		 RETRY_530,ResMgr::ERegExpValidate,0},
    {"ftp:retry-530-anonymous",	 "Login incorrect",ResMgr::ERegExpValidate,0},
    {"hftp:cache",		 "yes",   ResMgr::BoolValidate,0},
@@ -325,6 +326,9 @@ static ResType lftp_vars[] = {
    {"dns:order",		 DEFAULT_ORDER, OrderValidate,0},
    {"dns:SRV-query",		 "no",	  ResMgr::BoolValidate,0},
    {"dns:use-fork",		 "yes",	  ResMgr::BoolValidate,ResMgr::NoClosure},
+#ifdef DNSSEC_LOCAL_VALIDATION
+   {"dns:strict-dnssec",	 "no",	  ResMgr::BoolValidate,0},
+#endif
 
    {"fish:shell",		 "/bin/sh",0,0},
    {"fish:connect-program",	 "ssh -a -x",0,0},
@@ -336,6 +340,7 @@ static ResType lftp_vars[] = {
    {"xfer:verify",		 "no",	  ResMgr::BoolValidate,ResMgr::NoClosure},
    {"xfer:verify-command",	 "",	  ResMgr::FileExecutable,0},
    {"xfer:log",			 "yes",	  ResMgr::BoolValidate,ResMgr::NoClosure},
+   {"xfer:auto-rename",		 "no",	  ResMgr::BoolValidate,ResMgr::NoClosure},
 
 #if USE_SSL
    {"ssl:ca-file",		 "",	  ResMgr::FileReadable,ResMgr::NoClosure},
